pyMagnum
========

pyMagnum is a Python implementation of a read only interface to the
Magnum Energy network.

`The Python package site <https://pypi.org/project/pymagnum/>`_

This software is not endorsed or supported by Magnum Energy, a product
of DMX Power LLC. https://www.magnum-dimensions.com/

Please read the documentation before installing this package.
Older versions of some operating systems, require you to use ``python3`` and ``pip3`` to use the Python 3 version of these tools.

If you have installed version 1.1.3 and it is working, there is no reason to upgrade to this version. The fundamental software is unchanged, although there are a few enhancements to functionality.

.. BUILDINFO

    production

`Documentation <https://pymagnum.readthedocs.io/>`_

`Changes <https://github.com/CharlesGodwin/pymagnum/blob/master/CHANGES.rst>`_
